@@ -49,7 +49,6 @@
 #include <QFile>
 #include <QFileInfo>
 #include <QFutureWatcher>
-#include <QMessageBox>
 #include <QSettings>
 #include <QThread>
 #include <QTimer>
@@ -256,6 +255,7 @@ FlatpakResource * FlatpakBackend::addAppFromFlatpakBundle(const QUrl &url)
         return nullptr;
     }
 
+    g_autoptr(GBytes) metadata = flatpak_bundle_ref_get_metadata(bundleRef);
     appstreamGz = flatpak_bundle_ref_get_appstream(bundleRef);
     if (appstreamGz) {
         g_autoptr(GZlibDecompressor) decompressor = nullptr;
@@ -289,7 +289,7 @@ FlatpakResource * FlatpakBackend::addAppFromFlatpakBundle(const QUrl &url)
             return nullptr;
         }
 
-        QList<AppStream::Component> components = metadata.components();
+        const QList<AppStream::Component> components = metadata.components();
         if (components.size()) {
             asComponent = AppStream::Component(components.first());
         } else {
@@ -297,16 +297,32 @@ FlatpakResource * FlatpakBackend::addAppFromFlatpakBundle(const QUrl &url)
             return nullptr;
         }
     } else {
-        asComponent = AppStream::Component();
         qWarning() << "No appstream metadata in bundle";
+
+        QTemporaryFile tempFile;
+        tempFile.setAutoRemove(false);
+        if (!tempFile.open()) {
+            qWarning() << "Failed to get metadata file";
+            return nullptr;
+        }
+
+        gsize len = 0;
+        QByteArray metadataContent = QByteArray((char *)g_bytes_get_data(metadata, &len));
+        tempFile.write(metadataContent);
+        tempFile.close();
+
+        // Parse the temporary file
+        QSettings setting(tempFile.fileName(), QSettings::NativeFormat);
+        setting.beginGroup(QLatin1String("Application"));
+
+        asComponent.setName(setting.value(QLatin1String("name")).toString());
+
+        tempFile.remove();
     }
 
-    gsize len = 0;
-    g_autoptr(GBytes) iconData = nullptr;
-    g_autoptr(GBytes) metadata = nullptr;
     FlatpakResource *resource = new FlatpakResource(asComponent, preferredInstallation(), this);
 
-    metadata = flatpak_bundle_ref_get_metadata(bundleRef);
+    gsize len = 0;
     QByteArray metadataContent = QByteArray((char *)g_bytes_get_data(metadata, &len));
     if (!updateAppMetadata(resource, metadataContent)) {
         delete resource;
@@ -314,17 +330,17 @@ FlatpakResource * FlatpakBackend::addAppFromFlatpakBundle(const QUrl &url)
         return nullptr;
     }
 
-    iconData = flatpak_bundle_ref_get_icon(bundleRef, 128);
+    g_autoptr(GBytes) iconData = flatpak_bundle_ref_get_icon(bundleRef, 128);
     if (!iconData) {
         iconData = flatpak_bundle_ref_get_icon(bundleRef, 64);
     }
 
     if (iconData) {
         gsize len = 0;
-        QPixmap pixmap;
         char * data = (char *)g_bytes_get_data(iconData, &len);
-        QByteArray icon = QByteArray(data, len);
-        pixmap.loadFromData(icon, "PNG");
+
+        QPixmap pixmap;
+        pixmap.loadFromData(QByteArray(data, len), "PNG");
         resource->setBundledIcon(pixmap);
     }
 
@@ -658,7 +674,14 @@ bool FlatpakBackend::loadInstalledApps(FlatpakInstallation *flatpakInstallation)
             continue;
         }
 
-        AppStream::Component appstreamComponent(metadata.component());
+        const AppStream::Component appstreamComponent(metadata.component());
+
+        const auto res = getAppForInstalledRef(flatpakInstallation, ref);
+        if (res) {
+            res->setState(AbstractResource::Installed);
+            continue;
+        }
+
         FlatpakResource *resource = new FlatpakResource(appstreamComponent, flatpakInstallation, this);
 
         resource->setIconPath(pathExports);
@@ -666,23 +689,7 @@ bool FlatpakBackend::loadInstalledApps(FlatpakInstallation *flatpakInstallation)
         resource->setOrigin(QString::fromUtf8(flatpak_installed_ref_get_origin(ref)));
         resource->updateFromRef(FLATPAK_REF(ref));
 
-        // Go through apps we already know about from appstream metadata
-        bool resourceExists = false;
-        foreach (FlatpakResource *res, m_resources) {
-            // Compare the only information we have
-            if (res->appstreamId() == QStringLiteral("%1.desktop").arg(resource->appstreamId()) && res->name() == resource->name()) {
-                resourceExists = true;
-                res->setState(resource->state());
-                break;
-            }
-        }
-
-        if (!resourceExists) {
-            addResource(resource);
-        } else {
-            emit resourceRemoved(resource);
-            resource->deleteLater();
-        }
+        addResource(resource);
     }
 
     return true;
@@ -1054,6 +1061,13 @@ int FlatpakBackend::updatesCount() const
     return m_updater->updatesCount();
 }
 
+bool FlatpakBackend::flatpakResourceLessThan(AbstractResource* l, AbstractResource* r)
+{
+    return (l->isInstalled() != r->isInstalled()) ? l->isInstalled()
+         : (l->origin() != r->origin()) ? l->origin() < r->origin()
+         : l < r;
+}
+
 ResultsStream * FlatpakBackend::search(const AbstractResourcesBackend::Filters &filter)
 {
     if (filter.resourceUrl.fileName().endsWith(QLatin1String(".flatpakrepo")) || filter.resourceUrl.fileName().endsWith(QLatin1String(".flatpakref"))) {
@@ -1070,7 +1084,7 @@ ResultsStream * FlatpakBackend::search(const AbstractResourcesBackend::Filters &
         fetchResourceJob->start();
 
         return stream;
-    } else if (!filter.resourceUrl.isEmpty() && filter.resourceUrl.scheme() != QLatin1String("appstream"))
+    } else if ((!filter.resourceUrl.isEmpty() && filter.resourceUrl.scheme() != QLatin1String("appstream")) || !filter.extends.isEmpty())
         return new ResultsStream(QStringLiteral("FlatpakStream-void"), {});
 
     QVector<AbstractResource*> ret;
@@ -1089,6 +1103,8 @@ ResultsStream * FlatpakBackend::search(const AbstractResourcesBackend::Filters &
             ret += r;
         }
     }
+    auto f = [this](AbstractResource* l, AbstractResource* r) { return flatpakResourceLessThan(l,r); };
+    std::sort(ret.begin(), ret.end(), f);
     return new ResultsStream(QStringLiteral("FlatpakStream"), ret);
 }
 
