@@ -109,22 +109,23 @@ KNSBackend::KNSBackend(QObject* parent, const QString& iconName, const QString &
 
     m_engine = new KNSCore::Engine(this);
     m_engine->init(m_name);
-#if KNEWSTUFFCORE_VERSION_MAJOR==5 && KNEWSTUFFCORE_VERSION_MINOR>=36
     m_engine->setPageSize(100);
-#endif
     // Setting setFetching to false when we get an error ensures we don't end up in an eternally-fetching state
     connect(m_engine, &KNSCore::Engine::signalError, this, [this](const QString &_error) {
         QString error = _error;
+        bool invalidFile = false;
         if(error == QLatin1Literal("All categories are missing")) {
             markInvalid(error);
             error = i18n("Invalid %1 backend, contact your distributor.", m_displayName);
+            invalidFile = true;
         }
         m_responsePending = false;
         Q_EMIT searchFinished();
         Q_EMIT availableForQueries();
         this->setFetching(false);
         qWarning() << "kns error" << objectName() << error;
-        passiveMessage(i18n("%1: %2", name(), error));
+        if (!invalidFile)
+            passiveMessage(i18n("%1: %2", name(), error));
     });
     connect(m_engine, &KNSCore::Engine::signalEntriesLoaded, this, &KNSBackend::receivedEntries, Qt::QueuedConnection);
     connect(m_engine, &KNSCore::Engine::signalEntryChanged, this, &KNSBackend::statusChanged, Qt::QueuedConnection);
@@ -231,6 +232,7 @@ void KNSBackend::receivedEntries(const KNSCore::EntryInternal::List& entries)
         m_engine->requestMoreData();
     } else {
         Q_EMIT availableForQueries();
+        setFetching(false);
     }
 }
 
