@@ -236,6 +236,15 @@ QDateTime ResourcesUpdatesModel::lastUpdate() const
     return ret;
 }
 
+double ResourcesUpdatesModel::updateSize() const
+{
+    double ret = 0.;
+    for(AbstractBackendUpdater* upd: m_updaters) {
+        ret += upd->updateSize();
+    }
+    return ret;
+}
+
 qint64 ResourcesUpdatesModel::secsToLastUpdate() const
 {
     return lastUpdate().secsTo(QDateTime::currentDateTime());
@@ -250,4 +259,9 @@ void ResourcesUpdatesModel::setTransaction(UpdateTransaction* transaction)
     Q_EMIT progressingChanged();
 }
 
+Transaction* ResourcesUpdatesModel::transaction() const
+{
+    return m_transaction.data();
+}
+
 #include "ResourcesUpdatesModel.moc"
